@@ -1,25 +1,7 @@
 # -*- coding:utf-8 -*-
-import os
-import sys
+from ._util import *
 
-def iswin():
-    platform = sys.platform
-    if platform == 'win32':
-        return True
-    else:
-        return False
 
-def isfile(_path):
-    if os.path.isfile(_path):
-        return True
-    else:
-        return False
-
-def isdir(_path):
-    if os.path.isdir(_path):
-        return True
-    else:
-        return False
 
 def copyfile(src_file,des_file):
     """
